@@ -1,18 +1,18 @@
 import logging
 import os
 from datetime import datetime, timezone
-from enum import StrEnum
 from google.cloud.logging.handlers import CloudLoggingHandler
 from pydantic import BaseModel, ConfigDict, Field
 from typing import Generic, Literal, Optional, TypeVar, Union, overload
-from maleo.types.dict import StringToStringDict
-from maleo.types.string import OptionalString
-from .config import Config
+from maleo.types.dict import StrToStrDict
+from maleo.types.misc import StrOrStrEnum
+from maleo.types.string import OptStr
+from .config import LogConfig
 from .enums import LoggerType
 
 
-EnvironmentT = TypeVar("EnvironmentT", str, StrEnum)
-ServiceKeyT = TypeVar("ServiceKeyT", str, StrEnum)
+EnvironmentT = TypeVar("EnvironmentT", bound=StrOrStrEnum)
+ServiceKeyT = TypeVar("ServiceKeyT", bound=StrOrStrEnum)
 
 
 # * We suggest to NOT use this class
@@ -30,8 +30,8 @@ class Base(
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        client_key: OptionalString = None,
-        config: Config,
+        client_key: OptStr = None,
+        config: LogConfig,
     ):
         self._type = type  # Declare logger type
 
@@ -69,7 +69,7 @@ class Base(
             self._name = base_name
 
         # Define log labels
-        self._labels: StringToStringDict = {
+        self._labels: StrToStrDict = {
             "logger_type": self._type.value,
             "service_environment": str(self._environment),
             "service_key": str(self._service_key),
@@ -171,7 +171,7 @@ class Application(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, Service
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.APPLICATION,
@@ -188,7 +188,7 @@ class Cache(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceKeyT])
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.CACHE,
@@ -206,7 +206,7 @@ class Client(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceKeyT]
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
         client_key: str,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.CLIENT,
@@ -223,7 +223,7 @@ class Controller(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceK
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.CONTROLLER,
@@ -240,7 +240,7 @@ class Database(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceKey
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.DATABASE,
@@ -257,7 +257,7 @@ class Exception(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceKe
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.EXCEPTION,
@@ -274,7 +274,7 @@ class Middleware(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceK
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.MIDDLEWARE,
@@ -291,7 +291,7 @@ class Repository(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceK
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.REPOSITORY,
@@ -308,7 +308,7 @@ class Service(Base[EnvironmentT, ServiceKeyT], Generic[EnvironmentT, ServiceKeyT
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
+        config: LogConfig,
     ):
         super().__init__(
             LoggerType.SERVICE,
@@ -325,7 +325,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Application[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -333,7 +333,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Cache[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -342,7 +342,7 @@ def create(
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
     client_key: str,
-    config: Config,
+    config: LogConfig,
 ) -> Client[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -350,7 +350,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Controller[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -358,7 +358,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Database[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -366,7 +366,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Exception[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -374,7 +374,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Middleware[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -382,7 +382,7 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Repository[EnvironmentT, ServiceKeyT]: ...
 @overload
 def create(
@@ -390,15 +390,15 @@ def create(
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    config: Config,
+    config: LogConfig,
 ) -> Service[EnvironmentT, ServiceKeyT]: ...
 def create(
     type: LoggerType = LoggerType.BASE,
     *,
     environment: Optional[EnvironmentT] = None,
     service_key: Optional[ServiceKeyT] = None,
-    client_key: OptionalString = None,
-    config: Config,
+    client_key: OptStr = None,
+    config: LogConfig,
 ) -> Union[
     Base[EnvironmentT, ServiceKeyT],
     Application[EnvironmentT, ServiceKeyT],
@@ -479,7 +479,7 @@ def create(
         )
 
 
-class ServiceLoggers(BaseModel, Generic[EnvironmentT, ServiceKeyT]):
+class ApplicationLoggers(BaseModel, Generic[EnvironmentT, ServiceKeyT]):
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
     application: Application[EnvironmentT, ServiceKeyT] = Field(
@@ -511,8 +511,8 @@ class ServiceLoggers(BaseModel, Generic[EnvironmentT, ServiceKeyT]):
         *,
         environment: Optional[EnvironmentT] = None,
         service_key: Optional[ServiceKeyT] = None,
-        config: Config,
-    ) -> "ServiceLoggers[EnvironmentT, ServiceKeyT]":
+        config: LogConfig,
+    ) -> "ApplicationLoggers[EnvironmentT, ServiceKeyT]":
         return cls(
             application=create(
                 LoggerType.APPLICATION,
